/*
 * Licensed Materials - Property of IBM
 * 
 * 		5724-I66
 * 
 * (C) Copyright IBM Corporation 2005. All Rights Reserved. 
 * 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 * 
 * DISCLAIMER:
 * The following [enclosed] code is sample code created by IBM
 * Corporation. This sample code is not part of any standard IBM product
 * and is provided to you solely for the purpose of assisting you in the
 * development of your applications. The code is provided 'AS IS',
 * without warranty of any kind IBM shall not be liable for any damages
 * arising out of your use of sample code, even if they have been
 * advised of the possibility of such damages.
 */ 

package com.emerged.bank;

import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import commonj.sdo.DataObject;
import com.ibm.websphere.sca.ServiceManager;

public class BankImpl {
	
	private com.ibm.websphere.sca.ServiceManager serviceManager = null;		
	private com.ibm.websphere.bo.BOFactory boFactory = null;
	private static BankBean bean = null;
	
	/**
	 * Default constructor.
	 */
	public BankImpl() {
		super();
		initialize();
	}

	private void initialize() {
		try{
			//get the service manager
			serviceManager = new com.ibm.websphere.sca.ServiceManager();
			//get the BO factory
			boFactory = (com.ibm.websphere.bo.BOFactory)serviceManager.locateService("com/ibm/websphere/bo/BOFactory");
			
			//initialize the bank application bean
			bean = new BankBean();
		}
		catch(Exception e){
			e.printStackTrace();
		}
	}
	
	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This should be used when passing this service to another reference api
	 * or if you want to invoke yourself asynchonously.
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	private Customer convertSDOCustomer(DataObject sdoCustomer){
		Customer c = null;

		if (sdoCustomer != null) {
			
			
			try {
	
				//get all the data from the SDO customer object
				String customerNumber     = sdoCustomer.getString("customerNumber");
				String dateProfileCreated = sdoCustomer.getString("dateProfileCreated");
				String SIN                = sdoCustomer.getString("SIN");
				String FName              = sdoCustomer.getString("FName");
				String LName              = sdoCustomer.getString("LName");
				DataObject sdoContactInfo = sdoCustomer.getDataObject("contactInfo");
				List sdoAccounts          = sdoCustomer.getList("accounts");
	
				//create a Customer object and set its data
				c = new Customer();			
				c.setCustomerNumber(customerNumber);
				c.setDateProfileCreated(dateProfileCreated);
				c.setSIN(SIN);
				c.setFName(FName);
				c.setLName(LName);
				
				ContactInfo ci = convertSDOContactInfo(sdoContactInfo);
				c.setContactInfo(ci);
				
				Account[] accounts = convertSDOAccounts(sdoAccounts);
				c.setAccounts(accounts);
				
			}
			catch(Exception e){
				e.printStackTrace();
				c = null;
			}
		}
		
		return c;
	}
	
	private ContactInfo convertSDOContactInfo(DataObject sdoContactInfo){
		ContactInfo ci = null;
		
		if (sdoContactInfo != null){
			
			
			try{
				//get all the data from the SDO contactinfo object	
			    String customerNumber = sdoContactInfo.getString("customerNumber");
			    String street = sdoContactInfo.getString("street");
			    String city = sdoContactInfo.getString("city");
			    String state = sdoContactInfo.getString("state");
			    String country = sdoContactInfo.getString("country");
			    String zip = sdoContactInfo.getString("zip");
			    String homePhoneNumber = sdoContactInfo.getString("homePhoneNumber");
			    String workPhoneNumber = sdoContactInfo.getString("workPhoneNumber");
			    String email = sdoContactInfo.getString("email");
	
				//create a ContactInfo object and set its data
				ci = new ContactInfo();		    
			    ci.setCustomerNumber(customerNumber);
			    ci.setStreet(street);
			    ci.setCity(city);
			    ci.setState(state);
			    ci.setCountry(country);
			    ci.setZip(zip);
			    ci.setHomePhoneNumber(homePhoneNumber);
			    ci.setWorkPhoneNumber(workPhoneNumber);
			    ci.setEmail(email);
			}
			catch(Exception e){
				e.printStackTrace();
				ci = null;
			}
		}
		
		return ci;
	}
	
	private Account[] convertSDOAccounts(List accountsList) {
		Account[] accounts = null;

		if (accountsList != null){
			
		
			try {
	
	
				int iNumberOfAccounts = accountsList.size();
				
				//create an array of Account objects
				accounts = new Account[iNumberOfAccounts];
				int i=0;
				DataObject sdoAccount = null;
				
				//go through the list containing SDO account objects				
				Iterator it = accountsList.iterator();
				while(it.hasNext()){
					sdoAccount = (DataObject)it.next();
					//convert sdo account objects to an Account object
					accounts[i++] = convertSDOAccount(sdoAccount);
				}//while
	
			}
			catch(Exception e){
				e.printStackTrace();
				accounts = null;
			}
		}
		
		return accounts;
	}
	
	private Account convertSDOAccount(DataObject sdoAccount){
		Account account = null;
		
		if (sdoAccount != null) {
			
		
			try {
				//get all the data from the SDO account object				
			    String accountNumber           = sdoAccount.getString("accountNumber");
			    String type                    = sdoAccount.getString("type");
			    double maxDailyWithdrawalLimit = sdoAccount.getDouble("maxDailyWithdrawalLimit");
			    double balance                 = sdoAccount.getDouble("balance");
			    String description             = sdoAccount.getString("description");
			    
				//create an Account object and set its data			    
			    account = new Account();
			    account.setAccountNumber(accountNumber);
			    account.setType(type);
			    account.setMaximumDailyWithdrawalLimit( new Double(maxDailyWithdrawalLimit) );
			    account.setBalance( new Double(balance) );
			    account.setDescription(description);
			}
			catch(Exception e){
				e.printStackTrace();
			}

		}
		
		return account;
	}
	
	private DataObject convertToSDOCustomer(Customer c){
		DataObject sdoCustomer = null;
		
		if (c != null){
			
			try {
				
				//create the Customer sdo data object and set its properties
				sdoCustomer = boFactory.create("http://BankModule/com/emerged/bank", "CustomerBO");
				
				sdoCustomer.setString("customerNumber",c.getCustomerNumber());
				sdoCustomer.setString("dateProfileCreated",c.getDateProfileCreated());
				sdoCustomer.setString("SIN",c.getSIN());
				sdoCustomer.setString("FName",c.getFName());
				sdoCustomer.setString("LName",c.getLName());
				sdoCustomer.setDataObject("contactInfo",convertToSDOContactInfo(c.getContactInfo()));
				
				sdoCustomer.setList("accounts",convertToSDOAccounts(c.getAccounts()));
				
			}
			catch(Exception e){
		          e.printStackTrace();
		          sdoCustomer = null;
			}
			
		}
		
		return sdoCustomer;
	}

	private DataObject convertToSDOContactInfo(ContactInfo ci){
		DataObject sdoContactInfo = null;
		
		if (ci != null) {
		   try{
		   	
		   	//create the ContactInfo sdo object and set its properties
		   	sdoContactInfo = boFactory.create("http://BankModule/com/emerged/bank", "ContactInfoBO");
		   	
		   	sdoContactInfo.setString("customerNumber",ci.getCustomerNumber());
		   	sdoContactInfo.setString("street",ci.getStreet());
		   	sdoContactInfo.setString("city",ci.getCity());
		   	sdoContactInfo.setString("state",ci.getState());
		   	sdoContactInfo.setString("country",ci.getCountry());
		   	sdoContactInfo.setString("zip",ci.getZip());
		   	sdoContactInfo.setString("homePhoneNumber",ci.getHomePhoneNumber());
		   	sdoContactInfo.setString("workPhoneNumber",ci.getWorkPhoneNumber());
		   	sdoContactInfo.setString("email",ci.getEmail());
		   	
		   }
		   catch(Exception e){
		   	 e.printStackTrace();
		   	 sdoContactInfo = null;
		   }
		}
		
		return sdoContactInfo;
	}
	
	private List convertToSDOAccounts(Account[] accounts) {
	   List accountList = new Vector();
	   DataObject sdoAccount = null;
	   
	   if (accounts != null) {
	       for(int i=0;i<accounts.length;i++){
	       	  sdoAccount = convertToSDOAccount(accounts[i]);
	          accountList.add(sdoAccount);    	
	       }
	   }
	   
	   return accountList;
	}

	private DataObject convertToSDOAccountList(Account[] accounts) {
		   
		DataObject sdoAccountList = null;
		
		if (accounts != null){
			
		    List accountList = null;
		    DataObject sdoAccount = null;
			
			try {
				
				//create the AccountList sdo data object and set its properties
				sdoAccountList = boFactory.create("http://BankModule/com/emerged/bank", "AccountListBO");

				
				//convert Account objects into sdo account objects
		        accountList = new Vector();
		        for(int i=0;i<accounts.length;i++){
		       	  sdoAccount = convertToSDOAccount(accounts[i]);
		          accountList.add(sdoAccount);    	
		        }
		        //set the value property to the list of sdo account objects
		        sdoAccountList.setList("value",accountList);
		        
			}
			catch(Exception e){
				e.printStackTrace();
				sdoAccountList = null;
			}
		}
		
		
		return sdoAccountList;
		
	}

	private DataObject convertToSDOAccount(Account account){
		DataObject sdoAccount = null;
		Double amount = null;
		if (account != null){
			try {
				
				//create the Account sdo data object and set its properties
				sdoAccount = boFactory.create("http://BankModule/com/emerged/bank", "AccountBO");
				
				sdoAccount.setString("accountNumber",account.getAccountNumber());
				sdoAccount.setString("type",account.getType());
				
				amount = account.getMaximumDailyWithdrawalLimit();
				if (amount != null){
				   sdoAccount.setDouble("maxDailyWithdrawalLimit",amount.doubleValue());
				}

				amount = account.getBalance();
				if (amount != null){
					sdoAccount.setDouble("balance",amount.doubleValue());					
				}
				
				sdoAccount.setString("description",account.getDescription());				
			}
			catch(Exception e){
				e.printStackTrace();
				sdoAccount = null;
			}
		}
		
		
		return sdoAccount;
	}
	/**
	 * Method generated to support implemention of operation "createCustomer" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject createCustomer(DataObject inputCustomer) {

		DataObject outputCustomer = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			//call the bank application
			Customer oc = bean.createCustomer(ic);
			
			//convert the Customer object into an sdo customer object
			outputCustomer = convertToSDOCustomer(oc);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCustomer;		
	}

	/**
	 * Method generated to support implemention of operation "retrieveCustomer" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject retrieveCustomer(DataObject inputCustomer) {
		DataObject outputCustomer = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			//call the bank application
			Customer oc = bean.retrieveCustomer(ic);
			
			//convert the Customer object into an sdo customer object
			outputCustomer = convertToSDOCustomer(oc);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCustomer;		
	}

	/**
	 * Method generated to support implemention of operation "updateCustomer" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject updateCustomer(DataObject inputCustomer) {
		DataObject outputCustomer = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			//call the bank application
			Customer oc = bean.updateCustomer(ic);
			
			//convert the Customer object into an sdo customer object
			outputCustomer = convertToSDOCustomer(oc);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCustomer;		
	}

	/**
	 * Method generated to support implemention of operation "deleteCustomer" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject deleteCustomer(DataObject inputCustomer) {
		DataObject outputCustomer = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			//call the bank application
			Customer oc = bean.deleteCustomer(ic);
			
			//convert the Customer object into an sdo customer object
			outputCustomer = convertToSDOCustomer(oc);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCustomer;		
	}

	/**
	 * Method generated to support implemention of operation "createAccount" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject createAccount(DataObject inputCustomer,
			DataObject inputAccount) {
		
		DataObject outputAccount = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			//convert sdo account object into an Account object
			Account  ia = convertSDOAccount(inputAccount);
			
			//call the bank application
			Account oa = bean.createAccount(ic,ia);
			
			//convert the Account object into an account sdo object
			outputAccount = convertToSDOAccount(oa);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputAccount;
	}

	/**
	 * Method generated to support implemention of operation "retrieveAccount" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject retrieveAccount(DataObject inputAccount) {
		DataObject outputAccount = null;
		
		try {
		
			
			//convert sdo account object into an Account object
			Account  ia = convertSDOAccount(inputAccount);
			
			//call the bank application
			Account oa = bean.retrieveAccount(ia);
			
			//convert the Account object into an sdo object
			outputAccount = convertToSDOAccount(oa);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputAccount;
	}

	/**
	 * Method generated to support implemention of operation "updateAccount" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject updateAccount(DataObject inputAccount) {
		DataObject outputAccount = null;
		
		try {
		
			
			//convert sdo account object into an Account object
			Account  ia = convertSDOAccount(inputAccount);
			
			//call the bank application
			Account oa = bean.updateAccount(ia);
			
			//convert the Account object into an sdo object
			outputAccount = convertToSDOAccount(oa);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputAccount;
	}

	/**
	 * Method generated to support implemention of operation "deleteAccount" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject deleteAccount(DataObject inputCustomer,
			DataObject inputAccount) {
		DataObject outputAccount = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			//convert sdo account object into an Account object
			Account  ia = convertSDOAccount(inputAccount);
			
			//call the bank application
			Account oa = bean.deleteAccount(ic,ia);
			
			//convert the Account object into an sdo object
			outputAccount = convertToSDOAccount(oa);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputAccount;
	}

	/**
	 * Method generated to support implemention of operation "createContactInfo" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject createContactInfo(DataObject inputContactInfo) {
		DataObject outputContactInfo = null;
		
		try {
		
			//convert sdo contactinfo object into a ContactInfo object
			ContactInfo  ic = convertSDOContactInfo(inputContactInfo);
			
			//call the bank application
			ContactInfo  oc = bean.createContactInfo(ic);
			
			//convert the ContactInfo object into a contactinfo sdo object
			outputContactInfo = convertToSDOContactInfo(oc);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputContactInfo;
	}

	/**
	 * Method generated to support implemention of operation "retrieveContactInfo" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject retrieveContactInfo(DataObject inputContactInfo) {
		DataObject outputContactInfo = null;
		
		try {
		
			//convert sdo contactinfo object into a ContactInfo object
			ContactInfo  ic = convertSDOContactInfo(inputContactInfo);
			
			//call the bank application
			ContactInfo  oc = bean.retrieveContactInfo(ic);
			
			//convert the ContactInfo object into a contactinfo sdo object
			outputContactInfo = convertToSDOContactInfo(oc);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputContactInfo;
	}

	/**
	 * Method generated to support implemention of operation "updateContactInfo" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject updateContactInfo(DataObject inputContactInfo) {
		DataObject outputContactInfo = null;
		
		try {
		
			//convert sdo contactinfo object into a ContactInfo object
			ContactInfo  ic = convertSDOContactInfo(inputContactInfo);
			
			//call the bank application
			ContactInfo  oc = bean.updateContactInfo(ic);
			
			//convert the ContactInfo object into a contactinfo sdo object
			outputContactInfo = convertToSDOContactInfo(oc);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputContactInfo;
	}

	/**
	 * Method generated to support implemention of operation "deleteContactInfo" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject deleteContactInfo(DataObject inputContactInfo) {
		DataObject outputContactInfo = null;
		
		try {
		
			//convert sdo contactinfo object into a ContactInfo object
			ContactInfo  ic = convertSDOContactInfo(inputContactInfo);
			
			//call the bank application
			ContactInfo  oc = bean.deleteContactInfo(ic);
			
			//convert the ContactInfo object into a contactinfo sdo object
			outputContactInfo = convertToSDOContactInfo(oc);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputContactInfo;
	}

	/**
	 * Method generated to support implemention of operation "getAccounts" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject getAccounts(DataObject customer) {
		DataObject outputAccountList = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(customer);
			
			//call the bank application
			Account[] accounts = bean.getAccounts(ic);
			
			//convert Account[] object into the sdo accountlist object
            outputAccountList = convertToSDOAccountList(accounts);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputAccountList;
	}

	/**
	 * Method generated to support implemention of operation "deposit" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject deposit(Double inputAmount, DataObject inputAccount) {
		DataObject outputAccount = null;
		
		try {
		
			//convert sdo account object into an Account object
			Account  ia = convertSDOAccount(inputAccount);
			
			//call the bank application
			Account oa = bean.deposit(ia,inputAmount);
			
			//convert the Account object into an sdo object
			outputAccount = convertToSDOAccount(oa);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputAccount;
	}

	/**
	 * Method generated to support implemention of operation "withdraw" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject withdraw(Double inputAmount, DataObject inputAccount) {
		DataObject outputAccount = null;
		
		try {
		
			//convert sdo account object into an Account object
			Account  ia = convertSDOAccount(inputAccount);
			
			//call the bank application
			Account oa = bean.withdraw(ia,inputAmount);
			
			//convert the Account object into an sdo object
			outputAccount = convertToSDOAccount(oa);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputAccount;
	}

	/**
	 * Method generated to support implemention of operation "transfer" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject transfer(DataObject inputAccountFrom, Double inputAmount,
			DataObject inputAccountTo) {
		DataObject outputAccount = null;
		
		try {
		
			
			//convert sdo account object into an Account object
			Account  iaf = convertSDOAccount(inputAccountFrom);

			//convert sdo account object into an Account object
			Account  iat = convertSDOAccount(inputAccountTo);
			
			//call the bank application
			Account oa = bean.transfer(iaf,iat,inputAmount);
			
			//convert the Account object into an sdo object
			outputAccount = convertToSDOAccount(oa);

		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputAccount;
	}

	/**
	 * Method generated to support implemention of operation "isWebLoginValid" defined for WSDL port type 
	 * named "interface.Bank".
	 * 
	 * Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public Boolean isWebLoginValid(String customerName, String password) {
		
		boolean result = false;
		
		try {
		
			result = bean.isWebLoginInfoValid(customerName,password);
           
		}
		catch(Exception e){
	        e.printStackTrace();			
		}

		return new Boolean(result);
	}

}