/*
 * Licensed Materials - Property of IBM
 * 
 * 		5724-I66
 * 
 * (C) Copyright IBM Corporation 2005. All Rights Reserved. 
 * 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 * 
 * DISCLAIMER:
 * The following [enclosed] code is sample code created by IBM
 * Corporation. This sample code is not part of any standard IBM product
 * and is provided to you solely for the purpose of assisting you in the
 * development of your applications. The code is provided 'AS IS',
 * without warranty of any kind IBM shall not be liable for any damages
 * arising out of your use of sample code, even if they have been
 * advised of the possibility of such damages.
 */ 

package com.emerged.bank;

import java.sql.*;




public class CreateBankDatabase {

    
    private static com.ibm.db2j.jdbc.DB2jDataSource ds = null;
    private static Connection c = null;
    private static String sFileSeparator = java.io.File.separator;
    
	public static void main(String[] args) {
		
		
  try {

  	 
     startUp();

     System.out.println("Creating and connecting to the " + BankDatabaseConstants.sDatabaseName + " database ...");    
     Connection conn = getConnection();
     System.out.println(" ");          

     Statement stmt = conn.createStatement(); 
  
     String[] dropTable = new String[]{"drop table customeraccounts","drop table accounts","drop table accountdescriptions","drop table contactinfo","drop table customers"};
     
     System.out.println("Dropping existing tables...");
     for(int i=0;i<dropTable.length;i++){
     	
	     try {
	        //drop table
	        stmt.execute( dropTable[i] ); 
	        System.out.println(dropTable[i]);
	     }//try
	     catch(Exception e) {
	         //if table doesn't exist, no sense reporting that drop failed.
	     }
     }//for

     //create the tables
     
     System.out.println("   ");     
     System.out.println("Creating ACCOUNTDESCRIPTIONS table...");                 
     stmt.execute( "create table accountdescriptions (type varchar(1) not null, description varchar(15),constraint accountdescriptions_pk primary key (type) )"); 
      

     
     System.out.println("Creating CUSTOMERS table...");                 
     stmt.execute( "create table customers (customernumber varchar(10) not null ,dateprofilecreated varchar(10), sin varchar(15), firstname varchar(30),lastname varchar(30),constraint customers_pk primary key (customernumber) )"); 
      
     

     System.out.println("Creating ACCOUNTS table...");                      
     stmt.execute( "create table accounts (accountnumber varchar(7) not null, balance double precision, type varchar(1) not null , maxDailyWithdrawalLimit double precision ,constraint accounts_pk primary key (accountnumber),constraint accounts_fk foreign key (type) references accountdescriptions (type)  )"); 
      
          
               
     System.out.println("Creating CUSTOMERACCOUNTS table...");                      
     stmt.execute( "create table customeraccounts (customernumber varchar(10) not null, accountnumber varchar(7) not null,constraint customeraccounts_pk primary key (customernumber,accountnumber) )"); 
          

     
     System.out.println("Creating CONTACTINFO table...");                 
     stmt.execute( "create table contactinfo (customernumber varchar(10) not null,street varchar(30),city varchar(30),state varchar(30),country varchar(30),zip varchar(30),homephone varchar(15),workphone varchar(15),email varchar(30),constraint contactinfo_pk primary key (customernumber) )"); 
     System.out.println(" ");      
     
          
     
     
     //populate tables with data
     String accountNumber = null;
     

     String sCustomerNumber = null;
     String sDateProfileCreated = null;     
     String sSIN = null;
     String sFirstName = null;
     String sLastName = null;

     
     System.out.println("Inserting data into ACCOUNTDESCRIPTIONS table...");                                     

     stmt.execute( "insert into accountdescriptions values ('C', 'CHECKING')"); 
     stmt.execute( "insert into accountdescriptions values ('S', 'SAVING')");      
     
     
     System.out.println("Inserting data into CUSTOMERS table...");
     
     sCustomerNumber = "9999000000";
     sDateProfileCreated = "1972/08/25";
     sSIN = "111111111";
     sFirstName = "John";
     sLastName = "Doe";
     stmt.execute( "insert into customers values ('" + sCustomerNumber + "','" + sDateProfileCreated + "','" + sSIN + "','" + sFirstName + "','" + sLastName + "')");

     sCustomerNumber = "9999000001";
     sDateProfileCreated = "1979/08/25";     
     sSIN = "222222222";     
     sFirstName = "Jane";
     sLastName = "Doe";
     stmt.execute( "insert into customers values ('" + sCustomerNumber + "','" + sDateProfileCreated + "','" + sSIN + "','" + sFirstName + "','" + sLastName + "')");
     
     String sStreet = null;
     String sCity = null;
     String sState = null;
     String sCountry = null;
     String sZip = null;
     String sHomeNumber = null;
     String sWorkNumber = null;
     String sEmail = null;
     
     System.out.println("Inserting data into CONTACTINFO table...");
     
     sCustomerNumber = "9999000000";
     sStreet  = "Street1";
     sCity    = "City1";
     sState   = "State1";     
     sCountry = "Country1";
     sZip     = "Zip1";
     sHomeNumber = "905-555-1214";
     sWorkNumber = "905-555-1215";
     sEmail = "johndoe@whatever.com";     
     
     stmt.execute( "insert into contactinfo values ('" + sCustomerNumber + "','" + sStreet + "','" + sCity  + "','" + sState + "','" + sCountry + "','" + sZip + "','" + sHomeNumber + "','" + sWorkNumber+ "','" + sEmail + "')");
     
     sCustomerNumber = "9999000001";
     sStreet  = "Street2";
     sCity    = "City2";
     sState   = "State2";     
     sCountry = "Country2";
     sZip     = "Zip2";
     sHomeNumber = "905-555-1212";
     sWorkNumber = "905-555-1213";
     sEmail = "janedoe@whatever.com";
     
     stmt.execute( "insert into contactinfo values ('" + sCustomerNumber + "','" + sStreet + "','" + sCity  + "','" + sState + "','" + sCountry + "','" + sZip + "','" + sHomeNumber + "','" + sWorkNumber+ "','" + sEmail + "')");


     
     System.out.println("Inserting data into ACCOUNTS table...");                           
     
     accountNumber = "1000000";
     stmt.execute( "insert into accounts values ('" + accountNumber + "', 1200.67,  'C', 300.00)");
     
     accountNumber = "1000001";
     stmt.execute( "insert into accounts values ('" + accountNumber + "',  25000.00,  'C', 300.00)"); 
     
     accountNumber = "1000002";     
     stmt.execute( "insert into accounts values ('" + accountNumber + "', 30000.01, 'S', 100.00)"); 


     accountNumber = "1000003";                    
     stmt.execute( "insert into accounts values ('" + accountNumber + "',  10.07,  'C', 300.00)"); 

     accountNumber = "1000004";     
     stmt.execute( "insert into accounts values ('" + accountNumber + "', 80000.00, 'S', 100.00)");
     
     accountNumber = "1000005";                         
     stmt.execute( "insert into accounts values ('" + accountNumber + "', 85000.00, 'S', 100.00)"); 

     
     System.out.println("Inserting data into CUSTOMERACCOUNTS table...");                           
     
     sCustomerNumber = "9999000000";
     accountNumber = "1000000";
     stmt.execute( "insert into customeraccounts values ('" + sCustomerNumber + "','" + accountNumber + "')");
     sCustomerNumber = "9999000000";
     accountNumber = "1000001";
     stmt.execute( "insert into customeraccounts values ('" + sCustomerNumber + "','" + accountNumber + "')");
     sCustomerNumber = "9999000000";
     accountNumber = "1000002";
     stmt.execute( "insert into customeraccounts values ('" + sCustomerNumber + "','" + accountNumber + "')");

     sCustomerNumber = "9999000001";
     accountNumber = "1000003";
     stmt.execute( "insert into customeraccounts values ('" + sCustomerNumber + "','" + accountNumber + "')");     
     sCustomerNumber = "9999000001";
     accountNumber = "1000004";
     stmt.execute( "insert into customeraccounts values ('" + sCustomerNumber + "','" + accountNumber + "')");     
     sCustomerNumber = "9999000001";
     accountNumber = "1000005";
     stmt.execute( "insert into customeraccounts values ('" + sCustomerNumber + "','" + accountNumber + "')");     
     
     //Display table info
     System.out.println("  ");     
     System.out.println("  ");     
     System.out.println("Displaying table data... ");               
     ResultSet result;

     System.out.println("SELECT * FROM ACCOUNTDESCRIPTIONS:");          
     result = stmt.executeQuery("SELECT * FROM accountdescriptions");
     while(result.next()) {
       System.out.println("type=" + result.getString("type") + ", " + "description=" + result.getString("description") );
     }
     System.out.println(" ");          
     System.out.println(" ");          
     
     
     System.out.println("   ");     
     System.out.println("SELECT * FROM CUSTOMERS:");   
     result = stmt.executeQuery("SELECT * FROM customers");

     while(result.next()) {
       System.out.println("   ");     	
       System.out.println("customernumber=" + result.getString("customernumber") + ",\n" +
       					  "dateprofilecreated="      + result.getString("dateprofilecreated") + ",\n" +       		
	                      "sin="      + result.getString("sin") + ",\n" +       		
       		              "firstname="      + result.getString("firstname") + ",\n" +
						  "lastname="       + result.getString("lastname")  );
     }
     System.out.println(" ");          
     System.out.println(" ");          
     
     System.out.println("SELECT * FROM CONTACTINFO:");   
     result = stmt.executeQuery("SELECT * FROM contactinfo");

     
     while(result.next()) {
       System.out.println("   ");     	
       System.out.println("customernumber=" + result.getString("customernumber") + ",\n" + 
       		              "street="      + result.getString("street") + ",\n" +
						  "city="       + result.getString("city") + ",\n" +
						  "state="       + result.getString("state") + ",\n" +						  
						  "country="      + result.getString("country") + ",\n" +
						  "zip="      + result.getString("zip") + ",\n" +
						  "homephone="      + result.getString("homephone") + ",\n" +
						  "workphone="      + result.getString("workphone") + ",\n" +						  
						  "email="      + result.getString("email")  );
     }
     System.out.println(" ");          
     System.out.println(" ");          
     
     System.out.println("SELECT * FROM ACCOUNTS:");          
     result = stmt.executeQuery("SELECT * FROM accounts");
     while(result.next()) {
       System.out.println("accountnumber=" + result.getString("accountnumber") + "," + "balance=" + result.getDouble("balance") + ", " + "type=" + result.getString("type") + ", " + "maxDailyWithdrawalLimit=" + result.getDouble("maxDailyWithdrawalLimit") );
     }
     System.out.println(" ");          
     System.out.println(" ");          

     System.out.println("SELECT * FROM CUSTOMERACCOUNTS:");          
     result = stmt.executeQuery("SELECT * FROM customeraccounts");
     while(result.next()) {
       System.out.println("customernumber=" + result.getString("customernumber") + "," + "accountnumber=" + result.getString("accountnumber")  );
     }
     System.out.println(" ");          
     System.out.println(" ");          
     
     


     finishUp();
          
     System.out.println("Successfully shut down " + BankDatabaseConstants.sDatabaseName + " database");     


  }//try
  catch(Throwable e) {
     System.out.println("Exception thrown.");
     System.out.println(e);
  }//catch
		
		
}

    private static void startDB() {

        try {    	
        	
        	
           //make sure db is created: use this style of URL -> jdbc:db2j:c:\cloudscapedbs\eMergedScenarioBankAccountDB;create=true
           Class.forName("com.ibm.db2j.jdbc.DB2jDriver").newInstance();             	  
           Connection temp = DriverManager.getConnection("jdbc:db2j:" + BankDatabaseConstants.sDBPath + sFileSeparator + BankDatabaseConstants.sDatabaseName + ";create=true");        	  
        	
           Class cds = Class.forName("com.ibm.db2j.jdbc.DB2jDataSource");
           ds = (com.ibm.db2j.jdbc.DB2jDataSource) cds.newInstance();
           ds.setDatabaseName(BankDatabaseConstants.sDBPath + sFileSeparator + BankDatabaseConstants.sDatabaseName);
            
        }
        catch(Exception e) {
               e.printStackTrace();
        }
    	
    }
        
    private static void closeDB()  {
    	
     try {

         if ( c != null) {         	
             c.close();
             c = null;
         }

     }
     catch(Exception e) {
     	e.printStackTrace();
     }

     try {
         DriverManager.getConnection("jdbc:db2j:" + BankDatabaseConstants.sDBPath + sFileSeparator + BankDatabaseConstants.sDatabaseName + ";shutdown=true");        	                	
     }
     catch(Exception e) {
     	//shutting down always throws an exception
     }    	    	
    	
    }

    private static void startUp()  {
    	
       startDB();	    	
    	
    }

    private static void finishUp()  {
    	
       closeDB();
    	
    }
    
     private static Connection getConnection() {

       try {
       	
          if ( c == null) {
   	           c = ds.getConnection();                	
          }
       }
       catch(Exception e) {
       	 e.printStackTrace();
       }

       return c;
          
     }
    

}
