/*
 * Licensed Materials - Property of IBM
 * 
 * 		5724-I66
 * 
 * (C) Copyright IBM Corporation 2005. All Rights Reserved. 
 * 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 * 
 * DISCLAIMER:
 * The following [enclosed] code is sample code created by IBM
 * Corporation. This sample code is not part of any standard IBM product
 * and is provided to you solely for the purpose of assisting you in the
 * development of your applications. The code is provided 'AS IS',
 * without warranty of any kind IBM shall not be liable for any damages
 * arising out of your use of sample code, even if they have been
 * advised of the possibility of such damages.
 */ 

package com.emerged.news;

import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import com.emerged.news.NewsBean;
import com.ibm.websphere.sca.Ticket;
import commonj.sdo.DataObject;
import com.ibm.websphere.sca.ServiceManager;

public class NewsArticlesMapImpl {
	/**
	 * Default constructor.
	 */
	com.ibm.websphere.sca.ServiceManager serviceManager = null;		
	com.ibm.websphere.bo.BOFactory boFactory = null;
	
	public NewsArticlesMapImpl() {
		super();
		initialize();		
	}

	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This method should be used when passing this service to a partner reference
	 * or if you want to invoke this component service asynchronously.    
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * This method is used to locate the service for the reference
	 * named "NewsBeanPartner".  This will return an instance of
	 * {@link NewsBean}.  If you would like to use this service 
	 * asynchronously then you will need to cast the result
	 * to {@link NewsBeanAsync}.
	 *
	 * @generated (com.ibm.wbit.java)
	 *
	 * @return NewsBean
	 */
	public NewsBean locateService_NewsBeanPartner() {
		return (NewsBean) ServiceManager.INSTANCE
				.locateService("NewsBeanPartner");
	}

	/**
	 * Method generated to support implemention of operation "getNewsArticlesByCategories" defined for WSDL port type 
	 * named "interface.NewsArticlesByCategoriesInterface".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject getNewsArticlesByCategories(DataObject categories) {
		//convert NewsCategoryList sdo data object to NewsCategory[]
		NewsCategory[] newsCategories = convertNewsCategoryList(categories);

		//get the NewsBean
		NewsBean nb = locateService_NewsBeanPartner();
		
		//get news articles based on news categories
		NewsArticle[] newsArticles = nb.getNewsArticles(newsCategories);

		//convert NewArticle[] to sdo data object NewsArticlesList
		DataObject  articles = convertToSDONewsArticlesList(newsArticles);
		
		return articles;
	}

	/**
	 * Method generated to support the async implementation using callback
	 * for the operation (@link com.emerged.news.NewsBean#getNewsArticles(DataObject aNewsCategory))
	 * of java interface (@link com.emerged.news.NewsBean)	
	 * @see com.emerged.news.NewsBean#getNewsArticles(DataObject aNewsCategory)	
	 */
	public void onGetNewsArticlesResponse(Ticket __ticket,
			DataObject returnValue, Exception exception) {
		//TODO Needs to be implemented.
	}

	/**
	 * Method generated to support the async implementation using callback
	 * for the operation (@link com.emerged.news.NewsBean#getNewsCategories())
	 * of java interface (@link com.emerged.news.NewsBean)	
	 * @see com.emerged.news.NewsBean#getNewsCategories()	
	 */
	public void onGetNewsCategoriesResponse(Ticket __ticket,
			DataObject returnValue, Exception exception) {
		//TODO Needs to be implemented.
	}

	private void initialize() {
		try{
			serviceManager = new com.ibm.websphere.sca.ServiceManager();
			boFactory = (com.ibm.websphere.bo.BOFactory)serviceManager.locateService("com/ibm/websphere/bo/BOFactory");
		}
		catch(Exception e){
			e.printStackTrace();
		}
	}
	
    private NewsCategory[] convertNewsCategoryList(DataObject dataObject) {
    	
    	NewsCategory[] newsCategories = null;
    	
    	//get the property "value" of type List
		List l = dataObject.getList("value");
   
		if ( (l != null) && (l.size() > 0) ) {
			
			newsCategories = new NewsCategory[ l.size() ];
			

			DataObject newsCategorySDO = null;
	        NewsCategory newsCategory = null;
	        
	        int      id;
	        String name;
	        int index=0;
			Iterator it = l.iterator();
			
			while(it.hasNext()) {
				
			  //get a NewsCategory sdo data object	
			  newsCategorySDO = (DataObject)it.next();
			  
			  id   = newsCategorySDO.getInt("id");
			  name = newsCategorySDO.getString("name");
			  
			  //create a NewsCategory object
			  newsCategories[index++] = new NewsCategory(id,name);  
			}
			
		}//if
		
		return newsCategories;
    }
	
	private DataObject convertToSDONewsArticlesList(NewsArticle[] newsArticles) {
	    //create a NewsArticleList sdo data object
		DataObject sdoObject = boFactory.create("http://eMergedLibrary/com/emerged/portal", "NewsArticleListBO");
		Vector v = new Vector();
	    
	    if (newsArticles != null){

	      for(int i=0;i<newsArticles.length;i++){
	      	  //create a NewsArticle sdo data object and add it to the list
	  	      v.add( convertToSDONewsArticle(newsArticles[i]) );
	      }
	    }

	   //set the "value" property to contain a list of NewsArticle sdo objects
	   sdoObject.set("value",v);

	   return sdoObject;

	}

	private DataObject convertToSDONewsArticle(NewsArticle newsArticle) {
		DataObject sdoObject = null;
		
		if (newsArticle != null){
			//create a NewsArticle sdo data object
			sdoObject = boFactory.create("http://eMergedLibrary/com/emerged/portal", "NewsArticleBO");
			//set the "title" property
			sdoObject.set("title",newsArticle.getTitle());
			//set the "url" property
			sdoObject.set("url" ,newsArticle.getUrl());
			//set the category property with a NewsCategory sdo data object
			sdoObject.setDataObject("category" ,convertToSDONewsCategory(newsArticle.getCategory()));
		}
		
		return sdoObject;
	}
	
	private DataObject convertToSDONewsCategory(NewsCategory newsCategory) {
		DataObject sdoObject = null;
		
		if (newsCategory != null) {
			//create the NewsCategory sdo data object
			sdoObject = boFactory.create("http://eMergedLibrary/com/emerged/portal", "NewsCategoryBO");
			//set the "id" property
			sdoObject.setInt("id",newsCategory.getId());
			//set the "name" property
			sdoObject.setString("name",newsCategory.getName());
		}
		
		return sdoObject;
	}
	
}